# CMeel Eigen

[![PyPI version](https://badge.fury.io/py/cmeel-eigen.svg)](https://pypi.org/project/cmeel-eigen)
[![Release](https://github.com/cmake-wheel/cmeel-eigen/actions/workflows/release.yml/badge.svg)](https://github.com/cmake-wheel/cmeel-boost/actions/workflows/eigen.yml)

[Eigen](https://gitlab.com/libeigen/eigen) distribution for cmeel packages.
